"""Top-level package for romeo."""

__author__ = """Breno Silva"""
__email__ = 'brenophp@gmail.com'
__version__ = '0.1.0'

from .romeo import romeo
from .init import init
from .logs import logs
from .score import score
from .train import train